<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About </source>
        <translation>Informacije </translation>
    </message>
    <message>
        <source>About</source>
        <translation>Informacije</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Verzija</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zatvori</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Doniraj</translation>
    </message>
    <message>
        <source>Contact</source>
        <translation>Kontakt</translation>
    </message>
</context>
<context>
    <name>AboutTab</name>
    <message>
        <source>License: </source>
        <translation>Licenca: </translation>
    </message>
    <message>
        <source>Screenshot and Annotation Tool</source>
        <translation>Alat za snimanje ekrana i komentiranje</translation>
    </message>
</context>
<context>
    <name>ActionSettingTab</name>
    <message>
        <source>Name</source>
        <translation>Ime</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Prečac</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Isprazni</translation>
    </message>
    <message>
        <source>Take Capture</source>
        <translation>Snimi sliku</translation>
    </message>
    <message>
        <source>Include Cursor</source>
        <translation>Uključi kursor</translation>
    </message>
    <message>
        <source>Delay</source>
        <translation>Odgodi</translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>s</translation>
    </message>
    <message>
        <source>Capture Mode</source>
        <translation>Način snimanja</translation>
    </message>
    <message>
        <source>Show image in Pin Window</source>
        <translation>Prikaži sliku u prikvačenom prozoru</translation>
    </message>
    <message>
        <source>Copy image to Clipboard</source>
        <translation>Kopiraj sliku u međuspremnik</translation>
    </message>
    <message>
        <source>Upload image</source>
        <translation>Prenesi sliku</translation>
    </message>
    <message>
        <source>Open image parent directory</source>
        <translation>Otvori nadređenu mapu slike</translation>
    </message>
    <message>
        <source>Save image</source>
        <translation>Spremi sliku</translation>
    </message>
    <message>
        <source>Hide Main Window</source>
        <translation>Sakrij glavni prozor</translation>
    </message>
</context>
<context>
    <name>ActionsSettings</name>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Actions Settings</source>
        <translation>Postavke radnje</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Radnja</translation>
    </message>
</context>
<context>
    <name>AddWatermarkOperation</name>
    <message>
        <source>Watermark Image Required</source>
        <translation>Potrebna je slika vodenog žiga</translation>
    </message>
    <message>
        <source>Please add a Watermark Image via Options &gt; Settings &gt; Annotator &gt; Update</source>
        <translation>Dodaj sliku vodenog žiga putem Opcije &gt; Postavke &gt; Komentari &gt; Aktualiziraj</translation>
    </message>
</context>
<context>
    <name>AnnotationSettings</name>
    <message>
        <source>Smooth Painter Paths</source>
        <translation>Zaglađivanje crtanih staza</translation>
    </message>
    <message>
        <source>When enabled smooths out pen and
marker paths after finished drawing.</source>
        <translation>Kad je aktivirano, zaglađuje staze
olovke i markera nakon crtanja.</translation>
    </message>
    <message>
        <source>Smooth Factor</source>
        <translation>Faktor zaglađivanja</translation>
    </message>
    <message>
        <source>Increasing the smooth factor will decrease
precision for pen and marker but will
make them more smooth.</source>
        <translation>Povećanjem faktora zaglađivanja smanjit će se
točnost olovke i markera, ali će povećati
zaglađivanje.</translation>
    </message>
    <message>
        <source>Annotator Settings</source>
        <translation>Postavke komentara</translation>
    </message>
    <message>
        <source>Remember annotation tool selection and load on startup</source>
        <translation>Zapamti odabir alata za komentare i učitaj ga tijekom pokretanja programa</translation>
    </message>
    <message>
        <source>Switch to Select Tool after drawing Item</source>
        <translation>Prebaci na alat za biranje elemenata nakon crtanja elementa</translation>
    </message>
    <message>
        <source>Number Tool Seed change updates all Number Items</source>
        <translation>Mijenjanjem vrijednosti brojača, aktualiziraju se svi brojevni elementi</translation>
    </message>
    <message>
        <source>Disabling this option causes changes of the number tool
seed to affect only new items but not existing items.
Disabling this option allows having duplicate numbers.</source>
        <translation>Deaktiviranjem ove opcije brojač utječe samo na nove
elemente, ne i na postojeće. Na taj je način moguće
koristiti iste brojeve višestruko.</translation>
    </message>
    <message>
        <source>Canvas Color</source>
        <translation>Boja platna</translation>
    </message>
    <message>
        <source>Default Canvas background color for annotation area.
Changing color affects only new annotation areas.</source>
        <translation>Standardna boja pozadine platna za područje komentara.
Promjena boje utječe samo na nova područja komentara.</translation>
    </message>
    <message>
        <source>Select Item after drawing</source>
        <translation>Odabir element nakon crtanja</translation>
    </message>
    <message>
        <source>With this option enabled the item gets selected after
being created, allowing changing settings.</source>
        <translation>Kad je ova opcija aktivirana, element se odabire nakon
što se stvori i omogućuje mijenjanje postavki.</translation>
    </message>
</context>
<context>
    <name>ApplicationSettings</name>
    <message>
        <source>Capture screenshot at startup with default mode</source>
        <translation>Snimi sliku ekrana prilikom pokretanja programa sa standardnim modusom</translation>
    </message>
    <message>
        <source>Application Style</source>
        <translation>Stil programa</translation>
    </message>
    <message>
        <source>Sets the application style which defines the look and feel of the GUI.
Change requires ksnip restart to take effect.</source>
        <translation>Postavlja stil programa koji određuje izgled sučelja.
Promjene stupaju na snagu nakon ponovnog pokretanja ksnipa.</translation>
    </message>
    <message>
        <source>Application Settings</source>
        <translation>Postavke programa</translation>
    </message>
    <message>
        <source>Automatically copy new captures to clipboard</source>
        <translation>Automatski kopiraj nove snimke u međuspremnik</translation>
    </message>
    <message>
        <source>Use Tabs</source>
        <translation>Koristi kartice</translation>
    </message>
    <message>
        <source>Change requires restart.</source>
        <translation>Promjena zahtijeva ponovno pokretanje programa.</translation>
    </message>
    <message>
        <source>Run ksnip as single instance</source>
        <translation>Pokrenite samo jedan primjerak ksnipa</translation>
    </message>
    <message>
        <source>Hide Tabbar when only one Tab is used.</source>
        <translation>Sakrij traku kartica kad postoji samo jedna kartica.</translation>
    </message>
    <message>
        <source>Enabling this option will allow only one ksnip instance to run,
all other instances started after the first will pass its
arguments to the first and close. Changing this option requires
a new start of all instances.</source>
        <translation>Aktiviranjem ove opcije omogućuje se pokretanje samo jednog primjerka
programa ksnip, a sva naknadna pokretanja programa proslijedit će
svoje argumente prvom pokrenutom i zatim će se zatvoriti.
Mijenjanje ove opcije zahtijeva ponovno pokretanje svih primjeraka.</translation>
    </message>
    <message>
        <source>Remember Main Window position on move and load on startup</source>
        <translation>Zapamti položaj glavnog prozora prilikom premještanja i učitaj ga prilikom pokretanja programa</translation>
    </message>
    <message>
        <source>Auto hide Tabs</source>
        <translation>Automatski sakrij kartice</translation>
    </message>
    <message>
        <source>Auto hide Docks</source>
        <translation>Automatski sakrij ploče</translation>
    </message>
    <message>
        <source>On startup hide Toolbar and Annotation Settings.
Docks visibility can be toggled with the Tab Key.</source>
        <translation>Prilikom pokretanja sakrij alatnu traku i postavke komentara.
Vidljivost ploča može se promijeniti pomoću tipke tabulatora.</translation>
    </message>
    <message>
        <source>Auto resize to content</source>
        <translation>Automatski prilagodi veličinu sadržaju</translation>
    </message>
    <message>
        <source>Automatically resize Main Window to fit content image.</source>
        <translation>Automatski prilagodi veličinu glavnog prozora veličini slike sadržaja.</translation>
    </message>
    <message>
        <source>Enable Debugging</source>
        <translation>Aktiviraj ispravljanje grešaka</translation>
    </message>
    <message>
        <source>Enables debug output written to the console.
Change requires ksnip restart to take effect.</source>
        <translation>Aktivira rezultat ispravljanje grešaka ispisan u konzoli.
Promjena zahtijeva ponovno pokretanje ksnip-a da bi stupilo na snagu.</translation>
    </message>
    <message>
        <source>Resize to content delay</source>
        <translation>Promijeni veličinu na kašnjenje sadržaja</translation>
    </message>
    <message>
        <source>Resizing to content is delay to allow the Window Manager to receive
the new content. In case that the Main Windows is not adjusted correctly
to the new content, increasing this delay might improve the behavior.</source>
        <translation>Mijenjanje veličine sadržaja je odgoda kako bi se upravljaču prozora omogućilo primanje
novog sadržaja. U slučaju da glavni prozori nisu pravilno podešeni
na novi sadržaj, povećanje ovog kašnjenja moglo bi poboljšati ponašanje.</translation>
    </message>
</context>
<context>
    <name>AuthorTab</name>
    <message>
        <source>Contributors:</source>
        <translation>Doprinositelji:</translation>
    </message>
    <message>
        <source>Spanish Translation</source>
        <translation>Prijevod na španjolski</translation>
    </message>
    <message>
        <source>Dutch Translation</source>
        <translation>Prijevod na nizozemski</translation>
    </message>
    <message>
        <source>Russian Translation</source>
        <translation>Prijevod na ruski</translation>
    </message>
    <message>
        <source>Norwegian Bokmål Translation</source>
        <translation>Prijevod na norveški bokmål</translation>
    </message>
    <message>
        <source>French Translation</source>
        <translation>Prijevod na francuski</translation>
    </message>
    <message>
        <source>Polish Translation</source>
        <translation>Prijevod na poljski</translation>
    </message>
    <message>
        <source>Snap &amp; Flatpak Support</source>
        <translation>Snap i Flatpak podrška</translation>
    </message>
    <message>
        <source>The Authors:</source>
        <translation>Autori:</translation>
    </message>
</context>
<context>
    <name>CanDiscardOperation</name>
    <message>
        <source>Warning - </source>
        <translation>Upozorenje – </translation>
    </message>
    <message>
        <source>The capture %1%2%3 has been modified.
Do you want to save it?</source>
        <translation>Snimka %1%2%3 je promijenjena.
Želiš li je spremiti?</translation>
    </message>
</context>
<context>
    <name>CaptureModePicker</name>
    <message>
        <source>New</source>
        <translation>Novo</translation>
    </message>
    <message>
        <source>Draw a rectangular area with your mouse</source>
        <translation>Nacrtaj pravokutno područje pomoću miša</translation>
    </message>
    <message>
        <source>Capture full screen including all monitors</source>
        <translation>Snimi cijeli ekran uključujući sve monitore</translation>
    </message>
    <message>
        <source>Capture screen where the mouse is located</source>
        <translation>Snimi ekran na mjestu gdje se nalazi miš</translation>
    </message>
    <message>
        <source>Capture window that currently has focus</source>
        <translation>Snimi trenutačno aktivni prozor</translation>
    </message>
    <message>
        <source>Capture that is currently under the mouse cursor</source>
        <translation>Snimi ono što se nalazi ispod pokazivača miša</translation>
    </message>
    <message>
        <source>Capture a screenshot of the last selected rectangular area</source>
        <translation>Snimi sliku ekrana zadnjeg odabranog pravokutnog područja</translation>
    </message>
    <message>
        <source>Uses the screenshot Portal for taking screenshot</source>
        <translation>Koristi portal slika ekrana za snimanje slike ekrana</translation>
    </message>
</context>
<context>
    <name>ContactTab</name>
    <message>
        <source>Community</source>
        <translation>Zajednica</translation>
    </message>
    <message>
        <source>Bug Reports</source>
        <translation>Prijave grešaka</translation>
    </message>
    <message>
        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
        <translation>Ako imaš opća pitanja, ideje ili ako jednostavno želiš razgovarati o ksnipu,&lt;br/&gt;, pridruži se našem %1 ili našem %2 poslužitelju.</translation>
    </message>
    <message>
        <source>Please use %1 to report bugs.</source>
        <translation>Za prijavu grešaka koristi %1.</translation>
    </message>
</context>
<context>
    <name>CopyAsDataUriOperation</name>
    <message>
        <source>Failed to copy to clipboard</source>
        <translation>Neuspjelo kopiranje u međuspremnik</translation>
    </message>
    <message>
        <source>Failed to copy to clipboard as base64 encoded image.</source>
        <translation>Neuspjelo kopiranje u međuspremnik kao base64-kodiranu sliku.</translation>
    </message>
    <message>
        <source>Copied to clipboard</source>
        <translation>Kopirano u međuspremnik</translation>
    </message>
    <message>
        <source>Copied to clipboard as base64 encoded image.</source>
        <translation>Kopirano u međuspremnik kao base64-kodirana slika.</translation>
    </message>
</context>
<context>
    <name>DeleteImageOperation</name>
    <message>
        <source>Delete Image</source>
        <translation>Izbriši sliku</translation>
    </message>
    <message>
        <source>The item &apos;%1&apos; will be deleted.
Do you want to continue?</source>
        <translation>Izbrisat će se element „%1”.
Želiš li nastaviti?</translation>
    </message>
</context>
<context>
    <name>DonateTab</name>
    <message>
        <source>Donations are always welcome</source>
        <translation>Donacije su uvijek dobrodošle</translation>
    </message>
    <message>
        <source>Donation</source>
        <translation>Donacija</translation>
    </message>
    <message>
        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
        <translation>ksnip je neprofitabilan copyleft projekt slobodnog softvera i&lt;br/&gt;još uvijek ima neke troškove koje treba pokriti,&lt;br/&gt;poput troškova domene ili troškova hardvera za višeplatformsku podršku.</translation>
    </message>
    <message>
        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
        <translation>Ako želiš pomoći ili ako samo želiš cijeniti obavljeni posao&lt;br/&gt;slobodno počastiti programere pivom ili kavom %1ovdje%2.</translation>
    </message>
    <message>
        <source>Become a GitHub Sponsor?</source>
        <translation>Želiš postati GitHub sponzor?</translation>
    </message>
    <message>
        <source>Also possible, %1here%2.</source>
        <translation>Također moguće %1ovdje%2.</translation>
    </message>
</context>
<context>
    <name>EmptyActionSettingTab</name>
    <message>
        <source>Add new actions by pressing the &apos;Add&apos; tab button.</source>
        <translation>Dodaj nove radnje pritiskom gumba „Dodaj”.</translation>
    </message>
</context>
<context>
    <name>EnumTranslator</name>
    <message>
        <source>Rectangular Area</source>
        <translation>Pravokutno područje</translation>
    </message>
    <message>
        <source>Last Rectangular Area</source>
        <translation>Zadnje pravokutno područje</translation>
    </message>
    <message>
        <source>Full Screen (All Monitors)</source>
        <translation>Cijeli ekran (svi monitori)</translation>
    </message>
    <message>
        <source>Current Screen</source>
        <translation>Trenutačni ekran</translation>
    </message>
    <message>
        <source>Active Window</source>
        <translation>Aktivni prozor</translation>
    </message>
    <message>
        <source>Window Under Cursor</source>
        <translation>Prozor ispod pokazivača</translation>
    </message>
    <message>
        <source>Screenshot Portal</source>
        <translation>Portal slika ekrana</translation>
    </message>
</context>
<context>
    <name>FtpUploaderSettings</name>
    <message>
        <source>Force anonymous upload.</source>
        <translation>Prisili anoniman prijenos.</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Korisničko ime</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Lozinka</translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation>FTP prenositelj</translation>
    </message>
</context>
<context>
    <name>HandleUploadResultOperation</name>
    <message>
        <source>Upload Successful</source>
        <translation>Prijenos je uspio</translation>
    </message>
    <message>
        <source>Unable to save temporary image for upload.</source>
        <translation>Nije moguće spremiti privremenu sliku za prijenos.</translation>
    </message>
    <message>
        <source>Unable to start process, check path and permissions.</source>
        <translation>Nije moguće pokrenuti postupak. Provjeri stazu i dozvole.</translation>
    </message>
    <message>
        <source>Process crashed</source>
        <translation>Postupak prekinut zbog greške</translation>
    </message>
    <message>
        <source>Process timed out.</source>
        <translation>Postupak je prekoračio vrijeme.</translation>
    </message>
    <message>
        <source>Process read error.</source>
        <translation>Greška u postupku čitanja.</translation>
    </message>
    <message>
        <source>Process write error.</source>
        <translation>Greška u postupku pisanja.</translation>
    </message>
    <message>
        <source>Web error, check console output.</source>
        <translation>Web-greška. Pregledaj rezultat u konzoli.</translation>
    </message>
    <message>
        <source>Upload Failed</source>
        <translation>Prijenos nije uspio</translation>
    </message>
    <message>
        <source>Script wrote to StdErr.</source>
        <translation>Skripta je zapisala u standardnu grešku (StdErr).</translation>
    </message>
    <message>
        <source>FTP Upload finished successfully.</source>
        <translation>FTP prijenos je uspješno završen.</translation>
    </message>
    <message>
        <source>Unknown error.</source>
        <translation>Nepoznata greška.</translation>
    </message>
    <message>
        <source>Connection Error.</source>
        <translation>Greška u vezi.</translation>
    </message>
    <message>
        <source>Permission Error.</source>
        <translation>Greška u dozvoli.</translation>
    </message>
    <message>
        <source>Upload script %1  finished successfully.</source>
        <translation>Prijenos skripta %1 uspješno završen.</translation>
    </message>
    <message>
        <source>Uploaded to %1</source>
        <translation>Preneseno na %1</translation>
    </message>
</context>
<context>
    <name>HotKeySettings</name>
    <message>
        <source>Enable Global HotKeys</source>
        <translation>Aktiviraj globalne tipkovničke prečace</translation>
    </message>
    <message>
        <source>Capture Rect Area</source>
        <translation>Snimi pravokutno područje</translation>
    </message>
    <message>
        <source>Capture Full Screen</source>
        <translation>Snimi cijeli ekran</translation>
    </message>
    <message>
        <source>Capture current Screen</source>
        <translation>Snimi trenutačni ekran</translation>
    </message>
    <message>
        <source>Capture active Window</source>
        <translation>Snimi aktivni prozor</translation>
    </message>
    <message>
        <source>Capture Window under Cursor</source>
        <translation>Snimi prozor ispod pokazivača</translation>
    </message>
    <message>
        <source>Global HotKeys</source>
        <translation>Globalni tipkovnički prečaci</translation>
    </message>
    <message>
        <source>Capture Last Rect Area</source>
        <translation>Snimi zadnje pravokutno područje</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Isprazni</translation>
    </message>
    <message>
        <source>Capture using Portal</source>
        <translation>Snimi koristeći portal</translation>
    </message>
    <message>
        <source>HotKeys are currently supported only for Windows and X11.
Disabling this option makes also the action shortcuts ksnip only.</source>
        <translation>Tipkovnički prečaci su trenutačno dostupni samo za Windows i X11.
Deaktiviranjem ove opcije također omogućuje prečace radnji samo za ksnip.</translation>
    </message>
</context>
<context>
    <name>ImageGrabberSettings</name>
    <message>
        <source>Capture mouse cursor on screenshot</source>
        <translation>Snimi pokazivač miša u sliku ekrana</translation>
    </message>
    <message>
        <source>Should mouse cursor be visible on
screenshots.</source>
        <translation>Da li prikazati pokazivač miša u
slikama ekrana.</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>Snimanje slika</translation>
    </message>
    <message>
        <source>Generic Wayland implementations that use
XDG-DESKTOP-PORTAL handle screen scaling
differently. Enabling this option will
determine the current screen scaling and
apply that to the screenshot in ksnip.</source>
        <translation>Generičke implementacije Waylanda koji koriste
XDG-DESKTOP-PORTAL različito upravljaju
skaliranjem ekrana. Aktiviranjem ove opcije
odredit će se trenutačno skaliranje ekrana i
primijeniti na sliku ekrana u ksnipu.</translation>
    </message>
    <message>
        <source>GNOME and KDE Plasma support their own Wayland
and the Generic XDG-DESKTOP-PORTAL screenshots.
Enabling this option will force KDE Plasma and
GNOME to use the XDG-DESKTOP-PORTAL screenshots.
Change in this option require a ksnip restart.</source>
        <translation>GNOME i KDE Plasma podržavaju vlastiti Wayland i
generičke XDG-DESKTOP-PORTAL slike ekrana.
Aktiviranjem ove opcije prisilit će KDE Plasma i GNOME
da koriste XDG-DESKTOP-PORTAL slike ekrana.
Mijenjanje ove opcije zahtijeva ponovno pokretanje ksnip-a.</translation>
    </message>
    <message>
        <source>Show Main Window after capturing screenshot</source>
        <translation>Pokaži glavni prozor nakon snimanja slike ekrana</translation>
    </message>
    <message>
        <source>Hide Main Window during screenshot</source>
        <translation>Sakrij glavni prozor tijekom snimanja slike ekrana</translation>
    </message>
    <message>
        <source>Hide Main Window when capturing a new screenshot.</source>
        <translation>Sakrij glavni prozor pri snimanju nove slike ekrana.</translation>
    </message>
    <message>
        <source>Show Main Window after capturing a new screenshot
when the Main Window was hidden or minimize.</source>
        <translation>Prikaži glavni prozor nakon snimanja nove snimke ekrana
kad je glavni prozor bio skriven ili smanjen.</translation>
    </message>
    <message>
        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
        <translation>Prisili generičku wayland (xdg-desktop-portal) snimku ekrana</translation>
    </message>
    <message>
        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
        <translation>Promijeni veličinu generičke wayland (xdg-desktop-portal) snimke ekrana</translation>
    </message>
</context>
<context>
    <name>ImgurHistoryDialog</name>
    <message>
        <source>Imgur History</source>
        <translation>Imgur povijest</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zatvori</translation>
    </message>
    <message>
        <source>Time Stamp</source>
        <translation>Vremenska oznaka</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Poveznica</translation>
    </message>
    <message>
        <source>Delete Link</source>
        <translation>Izbriši poveznicu</translation>
    </message>
</context>
<context>
    <name>ImgurUploader</name>
    <message>
        <source>Upload to imgur.com finished!</source>
        <translation>Prijenos na imgur.com je završen!</translation>
    </message>
    <message>
        <source>Received new token, trying upload again…</source>
        <translation>Primljen je novi token, pokušaj ponovnog prijenosa …</translation>
    </message>
    <message>
        <source>Imgur token has expired, requesting new token…</source>
        <translation>Imgur token je istekao, šalje se zahtijev se novim tokenom …</translation>
    </message>
</context>
<context>
    <name>ImgurUploaderSettings</name>
    <message>
        <source>Force anonymous upload</source>
        <translation>Prisili anonimni prijenos</translation>
    </message>
    <message>
        <source>Always copy Imgur link to clipboard</source>
        <translation>Uvijek kopiraj Imgur-poveznicu u međuspremnik</translation>
    </message>
    <message>
        <source>Client ID</source>
        <translation>ID klijenta</translation>
    </message>
    <message>
        <source>Client Secret</source>
        <translation>Tajna klijenta</translation>
    </message>
    <message>
        <source>PIN</source>
        <translation>PIN</translation>
    </message>
    <message>
        <source>Enter imgur Pin which will be exchanged for a token.</source>
        <translation>Upiši imgur pin koji će se zamijeniti za token.</translation>
    </message>
    <message>
        <source>Get PIN</source>
        <translation>Nabavi PIN</translation>
    </message>
    <message>
        <source>Get Token</source>
        <translation>Nabavi token</translation>
    </message>
    <message>
        <source>Imgur History</source>
        <translation>Imgur povijest</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Prijenos za Imgur</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Korisničko ime</translation>
    </message>
    <message>
        <source>Waiting for imgur.com…</source>
        <translation>Čekanje na imgur.com …</translation>
    </message>
    <message>
        <source>Imgur.com token successfully updated.</source>
        <translation>Imgur.com token uspješno aktualiziran.</translation>
    </message>
    <message>
        <source>Imgur.com token update error.</source>
        <translation>Greška aktualiziranja Imgur.com tokena.</translation>
    </message>
    <message>
        <source>After uploading open Imgur link in default browser</source>
        <translation>Nakon prijenosa otvori poveznicu na Imgur u standardnom pregledniku</translation>
    </message>
    <message>
        <source>Link directly to image</source>
        <translation>Poveži izravno na sliku</translation>
    </message>
    <message>
        <source>Base Url:</source>
        <translation>Osnovni URL:</translation>
    </message>
    <message>
        <source>Base url that will be used for communication with Imgur.
Changing requires restart.</source>
        <translation>Osnovni URL koji će se koristiti za komunikaciju s Imgurom.
Promjena zahtijeva ponovno pokretanje programa.</translation>
    </message>
    <message>
        <source>Clear Token</source>
        <translation>Poništi token</translation>
    </message>
</context>
<context>
    <name>LoadImageFromFileOperation</name>
    <message>
        <source>Unable to open image</source>
        <translation>Neuspjelo otvaranje slike</translation>
    </message>
    <message>
        <source>Unable to open image from path %1</source>
        <translation>Neuspjelo otvaranje slike iz %1</translation>
    </message>
</context>
<context>
    <name>MainToolBar</name>
    <message>
        <source>New</source>
        <translation>Novo</translation>
    </message>
    <message>
        <source>Delay in seconds between triggering
and capturing screenshot.</source>
        <translation>Zadrška u sekundama između
okidanja i snimanja slike ekrana.</translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>s</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Spremi</translation>
    </message>
    <message>
        <source>Save Screen Capture to file system</source>
        <translation>Spremi snimku ekrana u datotečni sustav</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <source>Copy Screen Capture to clipboard</source>
        <translation>Kopiraj snimku ekrana u međuspremnik</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Alati</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Poništi</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Ponovi</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Obreži</translation>
    </message>
    <message>
        <source>Crop Screen Capture</source>
        <translation>Obreži snimku ekrana</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Unsaved</source>
        <translation>Nespremljeno</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Prenesi</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Ispiši</translation>
    </message>
    <message>
        <source>Opens printer dialog and provide option to print image</source>
        <translation>Otvara dijaloški okvir pisača i omogućuje ispisivanje slike</translation>
    </message>
    <message>
        <source>Print Preview</source>
        <translation>Pretprikaz ispisa</translation>
    </message>
    <message>
        <source>Opens Print Preview dialog where the image orientation can be changed</source>
        <translation>Otvara dijalog za pregled ispisa u kojem se može promijeniti orijentacija slike</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Skaliraj</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Zatvori program</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Postavke</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Informacije</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otvori</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Uredi</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>&amp;Opcije</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoć</translation>
    </message>
    <message>
        <source>Add Watermark</source>
        <translation>Dodaj vodeni žig</translation>
    </message>
    <message>
        <source>Add Watermark to captured image. Multiple watermarks can be added.</source>
        <translation>Dodaj vodeni žig snimljenoj slici. Moguće je dodati više vodenih žigova.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Datoteka</translation>
    </message>
    <message>
        <source>Unable to show image</source>
        <translation>Nije moguće prikazati sliku</translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>Spremi kao …</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Umetni</translation>
    </message>
    <message>
        <source>Paste Embedded</source>
        <translation>Umetni ugrađeno</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Prikvači</translation>
    </message>
    <message>
        <source>Pin screenshot to foreground in frameless window</source>
        <translation>Prikvači sliku ekrana naprijed u bezrubnom prozoru</translation>
    </message>
    <message>
        <source>No image provided but one was expected.</source>
        <translation>Nijedna slika nije zadana, ali očekuje se jedna.</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>Kopiraj stazu</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Otvori direktorij</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Prikaz</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Preimenuj</translation>
    </message>
    <message>
        <source>Open Images</source>
        <translation>Otvori slike</translation>
    </message>
    <message>
        <source>Show Docks</source>
        <translation>Prikaži ploče</translation>
    </message>
    <message>
        <source>Hide Docks</source>
        <translation>Sakrij ploče</translation>
    </message>
    <message>
        <source>Copy as data URI</source>
        <translation>Kopiraj kao URI podatke</translation>
    </message>
    <message>
        <source>Open &amp;Recent</source>
        <translation>Otvori &amp;nedavne</translation>
    </message>
    <message>
        <source>Modify Canvas</source>
        <translation>Promijeni platno</translation>
    </message>
    <message>
        <source>Upload triggerCapture to external source</source>
        <translation>Prenesi snimku ekrana u vanjski izvor</translation>
    </message>
    <message>
        <source>Copy triggerCapture to system clipboard</source>
        <translation>Kopiraj snimku ekrana u međuspremnik sustava</translation>
    </message>
    <message>
        <source>Scale Image</source>
        <translation>Promijeni veličinu slike</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Okreni</translation>
    </message>
    <message>
        <source>Rotate Image</source>
        <translation>Okreni sliku</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Radnje</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>Datoteke slika</translation>
    </message>
</context>
<context>
    <name>MultiCaptureHandler</name>
    <message>
        <source>Save</source>
        <translation>Spremi</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation>Spremi kao</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Otvori direktorij</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>Kopiraj stazu</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Preimenuj</translation>
    </message>
</context>
<context>
    <name>NewCaptureNameProvider</name>
    <message>
        <source>Capture</source>
        <translation>Snimi</translation>
    </message>
</context>
<context>
    <name>PinWindow</name>
    <message>
        <source>Close</source>
        <translation>Zatvori</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Zatvori ostale</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Zatvori sve</translation>
    </message>
</context>
<context>
    <name>PinWindowHandler</name>
    <message>
        <source>Pin Window %1</source>
        <translation>Prikvači prozor %1</translation>
    </message>
</context>
<context>
    <name>RenameOperation</name>
    <message>
        <source>Image Renamed</source>
        <translation>Slika je preimenovana</translation>
    </message>
    <message>
        <source>Image Rename Failed</source>
        <translation>Neuspjelo preimenovanje slike</translation>
    </message>
    <message>
        <source>Rename image</source>
        <translation>Preimenuj sliku</translation>
    </message>
    <message>
        <source>New filename:</source>
        <translation>Novo ime datoteke:</translation>
    </message>
    <message>
        <source>Successfully renamed image to %1</source>
        <translation>Slika uspješno preimenovana u %1</translation>
    </message>
    <message>
        <source>Failed to rename image to %1</source>
        <translation>Neuspjelo preimenovanje slike u %1</translation>
    </message>
</context>
<context>
    <name>SaveOperation</name>
    <message>
        <source>Save As</source>
        <translation>Spremi kao</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Sve datoteke</translation>
    </message>
    <message>
        <source>Image Saved</source>
        <translation>Slika je spremljena</translation>
    </message>
    <message>
        <source>Saving Image Failed</source>
        <translation>Spremanje slike neuspjelo</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>Datoteke slika</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Spremljeno u %1</translation>
    </message>
    <message>
        <source>Failed to save image to %1</source>
        <translation>Neuspjelo spremanje slike u %1</translation>
    </message>
</context>
<context>
    <name>SaverSettings</name>
    <message>
        <source>Automatically save new captures to default location</source>
        <translation>Automatski spremi nove snimke u standardno mjesto</translation>
    </message>
    <message>
        <source>Prompt to save before discarding unsaved changes</source>
        <translation>Zatraži spremanje prije odbacivanja nespremljenih promjena</translation>
    </message>
    <message>
        <source>Remember last Save Directory</source>
        <translation>Zapamti zadnji direktorij spremanja</translation>
    </message>
    <message>
        <source>When enabled will overwrite the save directory stored in settings
with the latest save directory, for every save.</source>
        <translation>Kad je aktivirano, prepisat će mapu za spremanje u postavkama
s najnovijom mapom za spremanje, za svako spremanje.</translation>
    </message>
    <message>
        <source>Capture save location and filename</source>
        <translation>Mjesto spremanja snimke i ime datoteke</translation>
    </message>
    <message>
        <source>Supported Formats are JPG, PNG and BMP. If no format provided, PNG will be used as default.
Filename can contain following wildcards:
- $Y, $M, $D for date, $h, $m, $s for time, or $T for time in hhmmss format.
- Multiple consecutive # for counter. #### will result in 0001, next capture would be 0002.</source>
        <translation>Podržani formati su JPG, PNG i BMP. Ako nije naveden nijedan format, standardno će se koristiti PNG.
Ime datoteke može sadržavati sljedeće zamjenske znakove:
- $Y, $M, $D za datum, $h, $m, $s za vrijeme ili $T za vrijeme u formatu „ hhmmss”.
- Više uzastopnih znakova „#” za brojač. „####” vraća 0001, slijedeće snimanje bit će 0002.</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Pretraži</translation>
    </message>
    <message>
        <source>Saver Settings</source>
        <translation>Postavke spremanja</translation>
    </message>
    <message>
        <source>Capture save location</source>
        <translation>Mjesto spremanja snimke</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standardno</translation>
    </message>
    <message>
        <source>Factor</source>
        <translation>Faktor</translation>
    </message>
    <message>
        <source>Save Quality</source>
        <translation>Kvaliteta spremanja</translation>
    </message>
    <message>
        <source>Specify 0 to obtain small compressed files, 100 for large uncompressed files.
Not all image formats support the full range, JPEG does.</source>
        <translation>Zadaj 0 za dobivanje male komprimirane datoteke, 100 za velike nekomprimirane datoteke.
Neki formati slika ne podržavaju cijeli raspon, JPEG ga podržava.</translation>
    </message>
</context>
<context>
    <name>ScriptUploaderSettings</name>
    <message>
        <source>Copy script output to clipboard</source>
        <translation>Kopiraj rezultat skripta u međuspremnik</translation>
    </message>
    <message>
        <source>Script:</source>
        <translation>Skripta:</translation>
    </message>
    <message>
        <source>Path to script that will be called for uploading. During upload the script will be called
with the path to a temporary png file as a single argument.</source>
        <translation>Staza do skripta koji se poziva za prijenos. Tijekom prijenosa pozvat će se skripta
sa stazom do privremene png datoteke kao jedan argument.</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Pretraži</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation>Prijenos skriptom</translation>
    </message>
    <message>
        <source>Select Upload Script</source>
        <translation>Odaberi skripta za prenošenje</translation>
    </message>
    <message>
        <source>Stop when upload script writes to StdErr</source>
        <translation>Prekini kad skripta prijenosa piše u standardnu grešku (StdErr)</translation>
    </message>
    <message>
        <source>Marks the upload as failed when script writes to StdErr.
Without this setting errors in the script will be unnoticed.</source>
        <translation>Označava prijenos kao neuspio, kad skripta piše u
standardnu grešku (StdErr). Bez ove postavke greške u
skriptu neće se primijetiti.</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filtar:</translation>
    </message>
    <message>
        <source>RegEx Expression. Only copy to clipboard what matches the RegEx Expression.
When omitted, everything is copied.</source>
        <translation>RegEx (regularni) izraz. Kopiraj u međuspremnik samo ono što se poklapa s
RegEx izrazom. Ako se izostavi, kopira se sve.</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Postavke</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>U redu</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Prekini</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>Snimanje slika</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Prijenos za Imgur</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Program</translation>
    </message>
    <message>
        <source>Annotator</source>
        <translation>Komentari</translation>
    </message>
    <message>
        <source>HotKeys</source>
        <translation>Tipkovnički prečaci</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>Prijenos</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation>Skripta za prijenos</translation>
    </message>
    <message>
        <source>Saver</source>
        <translation>Spremanje</translation>
    </message>
    <message>
        <source>Stickers</source>
        <translation>Naljepnice</translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation>Područje izrezivanja</translation>
    </message>
    <message>
        <source>Tray Icon</source>
        <translation>Ikona u programskoj traci</translation>
    </message>
    <message>
        <source>Watermark</source>
        <translation>Vodeni žig</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Radnje</translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation>FTP prenositelj</translation>
    </message>
</context>
<context>
    <name>SnippingAreaResizerInfoText</name>
    <message>
        <source>Resize selected rect using the handles or move it by dragging the selection.</source>
        <translation>Promijeni veličinu pravokutnog odabira pomoću ručki ili ga premjesti povlačenjem odabira.</translation>
    </message>
    <message>
        <source>Use arrow keys to move the selection.</source>
        <translation>Za premještanje odabira koristi tipke sa strelicama.</translation>
    </message>
    <message>
        <source>Use arrow keys while pressing CTRL to move top left handle.</source>
        <translation>Za micanje gornje lijeve ručke pritisni tipku CTRL i koristi tipke sa strelicama.</translation>
    </message>
    <message>
        <source>Use arrow keys while pressing ALT to move bottom right handle.</source>
        <translation>Za micanje donje desne ručke pritisni tipku ALT i koristi tipke sa strelicama.</translation>
    </message>
    <message>
        <source>Confirm selection by pressing ENTER/RETURN or abort by pressing ESC.</source>
        <translation>Potvrdi odabir pomoću tipke ENTER/RETURN ili prekini pomoću tipke ESC.</translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation>Ova se poruka može deaktivirati u postavkama.</translation>
    </message>
</context>
<context>
    <name>SnippingAreaSelectorInfoText</name>
    <message>
        <source>Click and Drag to select a rectangular area or press ESC to quit.</source>
        <translation>Za biranje pravokutnog područja pritisni-i-povuci miša ili pritisni ESC za prekid.</translation>
    </message>
    <message>
        <source>Hold CTRL pressed to resize selection after selecting.</source>
        <translation>Za mijenjanje veličine odabira pritisni tipku CTRL i drži je pritisnutom.</translation>
    </message>
    <message>
        <source>Hold CTRL pressed to prevent resizing after selecting.</source>
        <translation>Za sprečavanje mijenjanja veličine odabira pritisni tipku CTRL i drži je pritisnutom.</translation>
    </message>
    <message>
        <source>Operation will be canceled after 60 sec when no selection made.</source>
        <translation>Operacija će se prekinuti nakon 60 sekundi, ako se ništa ne odabere.</translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation>Ova se poruka može deaktivirati u postavkama.</translation>
    </message>
</context>
<context>
    <name>SnippingAreaSettings</name>
    <message>
        <source>Freeze Image while snipping</source>
        <translation>Zamrzni sliku tijekom izrezivanja</translation>
    </message>
    <message>
        <source>When enabled will freeze the background while
selecting a rectangular region. It also changes
the behavior of delayed screenshots, with this
option enabled the delay happens before the
snipping area is shown and with the option disabled
the delay happens after the snipping area is shown.
This feature is always disabled for Wayland and always
enabled for MacOs.</source>
        <translation>Kad je aktivirano, zamrznut će pozadinu tijekom
biranja pravokutnog područja. Također mijenja trajanje
zadrške prilikom snimanja ekrana. Kad je aktivirano,
zadrška se događa prije prikazivanja područja izrezivanja.
Kad deaktivirano, zadrška se događa nakon prikazivanja
područja izrezivanja. Ova je funkcija uvijek deaktivirana
za Wayland, a uvijek aktivirana za MacOS.</translation>
    </message>
    <message>
        <source>Show magnifying glass on snipping area</source>
        <translation>Pokaži povećalo u području izrezivanja</translation>
    </message>
    <message>
        <source>Show a magnifying glass which zooms into
the background image. This option only works
with &apos;Freeze Image while snipping&apos; enabled.</source>
        <translation>Pokaži povećalo koje povećava prikaz
slike pozadine. Ova opcija radi samo, kad je
„Zamrzni sliku tijekom izrezivanja” aktivirano.</translation>
    </message>
    <message>
        <source>Show Snipping Area rulers</source>
        <translation>Pokaži ravnala za područje izrezivanja</translation>
    </message>
    <message>
        <source>Horizontal and vertical lines going from
desktop edges to cursor on snipping area.</source>
        <translation>Vodoravne i okomite crte, koje se protežu od rubova
radne površine do pokazivača u području izrezivanja.</translation>
    </message>
    <message>
        <source>Show Snipping Area position and size info</source>
        <translation>Pokaži podatke ploložaja i veličine područja izrezivanja</translation>
    </message>
    <message>
        <source>When left mouse button is not pressed the position
is shown, when the mouse button is pressed,
the size of the select area is shown left
and above from the captured area.</source>
        <translation>Kad se lijeva tipka miša ne pritisne, prikazuje se položaj.
Kad se pritisne, veličina odabranog područja prikazuje se
lijevo iznad snimljenog područja.</translation>
    </message>
    <message>
        <source>Allow resizing rect area selection by default</source>
        <translation>Standardno dozvoli mijenjanje veličine pravokutnog područja</translation>
    </message>
    <message>
        <source>When enabled will, after selecting a rect
area, allow resizing the selection. When
done resizing the selection can be confirmed
by pressing return.</source>
        <translation>Kad je aktivirano, nakon biranja pravokutnog
područja dozvoli mijenjanje veličine odabira.
Promjena veličine odabira može se potvrditi
pritiskom tipke return.</translation>
    </message>
    <message>
        <source>Show Snipping Area info text</source>
        <translation>Pokaži tekst informacija područja izrezivanja</translation>
    </message>
    <message>
        <source>Snipping Area cursor color</source>
        <translation>Boja pokazivača za označivanje područja izrezivanja</translation>
    </message>
    <message>
        <source>Sets the color of the snipping area cursor.</source>
        <translation>Postavlja boju pokazivača za označivanje područja izrezivanja.</translation>
    </message>
    <message>
        <source>Snipping Area cursor thickness</source>
        <translation>Debljina pokazivača za označavanje područja izrezivanja</translation>
    </message>
    <message>
        <source>Sets the thickness of the snipping area cursor.</source>
        <translation>Postavlja debljinu pokazivača za označivanje područja izrezivanja.</translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation>Područje izrezivanja</translation>
    </message>
    <message>
        <source>Snipping Area adorner color</source>
        <translation>Ukrasna boja područja izrezivanja</translation>
    </message>
    <message>
        <source>Sets the color of all adorner elements
on the snipping area.</source>
        <translation>Postavlja boju svih ukrasnih elemenata
u području izrezivanja.</translation>
    </message>
    <message>
        <source>Snipping Area Transparency</source>
        <translation>Prozirnost područja izrezivanja</translation>
    </message>
    <message>
        <source>Alpha for not selected region on snipping area.
Smaller number is more transparent.</source>
        <translation>Prozirnost za neodabrano područje u području izrezivanja.
Manji broj znači veću prozirnost.</translation>
    </message>
</context>
<context>
    <name>StickerSettings</name>
    <message>
        <source>Up</source>
        <translation>Gore</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Dolje</translation>
    </message>
    <message>
        <source>Use Default Stickers</source>
        <translation>Koristi standardne naljepnice</translation>
    </message>
    <message>
        <source>Sticker Settings</source>
        <translation>Postavke naljepnica</translation>
    </message>
    <message>
        <source>Vector Image Files (*.svg)</source>
        <translation>Datoteke vektorskih slika (*.svg)</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Ukloni</translation>
    </message>
    <message>
        <source>Add Stickers</source>
        <translation>Dodaj naljepnice</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <source>Show Editor</source>
        <translation>Prikaži uređivač</translation>
    </message>
</context>
<context>
    <name>TrayIconSettings</name>
    <message>
        <source>Use Tray Icon</source>
        <translation>Koristi ikonu u programskoj traci</translation>
    </message>
    <message>
        <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
Change requires restart.</source>
        <translation>Kad je aktivirano, dodaje ikonu za programsku traku u traku zadataka, ako OS Windows Manager to podržava.
Promjena zahtijeva ponovno pokretanje programa.</translation>
    </message>
    <message>
        <source>Minimize to Tray</source>
        <translation>Smanji u programsku traku</translation>
    </message>
    <message>
        <source>Start Minimized to Tray</source>
        <translation>Pokreni smanjeno u programskoj traci</translation>
    </message>
    <message>
        <source>Close to Tray</source>
        <translation>Zatvori u programskoj traci</translation>
    </message>
    <message>
        <source>Show Editor</source>
        <translation>Prikaži uređivač</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>Snimi</translation>
    </message>
    <message>
        <source>Default Tray Icon action</source>
        <translation>Standardna radnja ikone u programskoj traci</translation>
    </message>
    <message>
        <source>Default Action that is triggered by left clicking the tray icon.</source>
        <translation>Standardna radnja koja se izvršava pri pritiskanju ikone u programskoj traci.</translation>
    </message>
    <message>
        <source>Tray Icon Settings</source>
        <translation>Postavke ikone u programskoj traci</translation>
    </message>
    <message>
        <source>Use platform specific notification service</source>
        <translation>Koristi uslugu obavještavanja platforme</translation>
    </message>
    <message>
        <source>When enabled will use try to use platform specific notification
service when such exists. Change requires restart to take effect.</source>
        <translation>Kad je aktivirano, pokušat će koristiti uslugu obavještavanja platforme
kad postoji. Zahtijeva ponovno pokretanje kako bi se promjena primijenila.</translation>
    </message>
    <message>
        <source>Display Tray Icon notifications</source>
        <translation>Prikaži obavijesti trake ikona</translation>
    </message>
</context>
<context>
    <name>UpdateWatermarkOperation</name>
    <message>
        <source>Select Image</source>
        <translation>Odaberi sliku</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>Datoteke slika</translation>
    </message>
</context>
<context>
    <name>UploadOperation</name>
    <message>
        <source>Upload Script Required</source>
        <translation>Potrebna je skripta za prijenos</translation>
    </message>
    <message>
        <source>Please add an upload script via Options &gt; Settings &gt; Upload Script</source>
        <translation>Dodaj skripta za prijenos putem Opcije &gt; Postavke &gt; Skripta za prijenos</translation>
    </message>
    <message>
        <source>Capture Upload</source>
        <translation>Prijenos snimke</translation>
    </message>
    <message>
        <source>You are about to upload the image to an external destination, do you want to proceed?</source>
        <translation>Prenijet ćeš sliku na vanjsko odredište. Želiš li nastaviti?</translation>
    </message>
</context>
<context>
    <name>UploaderSettings</name>
    <message>
        <source>Ask for confirmation before uploading</source>
        <translation>Zatraži potvrdu prije prenošenja</translation>
    </message>
    <message>
        <source>Uploader Type:</source>
        <translation>Vrsta prijenosa:</translation>
    </message>
    <message>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <source>Script</source>
        <translation>Skripta</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>Prijenos</translation>
    </message>
    <message>
        <source>FTP</source>
        <translation>FTP</translation>
    </message>
</context>
<context>
    <name>VersionTab</name>
    <message>
        <source>Version</source>
        <translation>Verzija</translation>
    </message>
    <message>
        <source>Build</source>
        <translation>Izgradnja</translation>
    </message>
    <message>
        <source>Using:</source>
        <translation>Koristi:</translation>
    </message>
</context>
<context>
    <name>WatermarkSettings</name>
    <message>
        <source>Watermark Image</source>
        <translation>Slika vodenog žiga</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Aktualiziraj</translation>
    </message>
    <message>
        <source>Rotate Watermark</source>
        <translation>Okreni vodeni žig</translation>
    </message>
    <message>
        <source>When enabled, Watermark will be added with a rotation of 45°</source>
        <translation>Kad je aktivirano, dodat će se vodeni žig okrenut za 45 stupnjeva</translation>
    </message>
    <message>
        <source>Watermark Settings</source>
        <translation>Postavke vodenog žiga</translation>
    </message>
</context>
</TS>
